﻿--[[---------------------------------------------------------------------------

Copyright (c) 2008 by K. Scott Piel 
All Rights Reserved

E-mail: < kscottpiel@gmail.com >
Web:    < http://www.scottpiel.com >

This file is part of nUI.

    nUI is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    nUI is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with nUI.  If not, see <http://www.gnu.org/licenses/>.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------
	
-------------------------------------------------------------------------------

function nUI:initOmen2()

	if nUI.AddOn.omen2 then
		
		if not nUI.info_frame.stats.omen2 then
				
			-- Omen uses two windows... one to select mode and one to display the
			-- stats. Rather than manage them separately, we just link them to a 
			-- single parent frame and use that to manage them
			
			local frame  = CreateFrame( "Frame", "$parent_Omen2", nUI.info_frame.stats );
			local config = Omen.ModuleList.Config;
	
			frame:SetAllPoints( nUI.info_frame.stats );
			nUI.info_frame.stats.omen2 = frame;
			
			OmenBarList:SetParent( frame );
			OmenBarList:Show();
			
			OmenModuleButtons:SetParent( frame );
			OmenModuleButtons:Show();			
			
			nUI:addInfoMode( "Omen", 
				function() 
					config:Show();
					if InCombatLockdown() or not nUI.AddOn.recount then frame:Show(); 
					else frame:Hide(); end
				end, 
				function() 
					config:Hide();
					frame:Hide(); 
				end 
			);		

			-- lose the unused panels
			
			OmenTitle:Hide();
			OmenResizeGrip:Hide();
			
			-- locate the buttons frame
			
			OmenModuleButtons:ClearAllPoints();
			OmenModuleButtons:SetScale( 0.5 );
			OmenModuleButtons:SetPoint( "BOTTOMLEFT", nUI.info_frame.stats, "BOTTOMLEFT", 0, 0 );
			OmenModuleButtons:SetPoint( "BOTTOMRIGHT", nUI.info_frame.stats, "BOTTOMRIGHT", 0, 0 );
			
			-- locate the bar frame
			
			OmenBarList:ClearAllPoints();
			OmenBarList:SetPoint( "TOPLEFT", nUI.info_frame.stats, "TOPLEFT", -2, 0 );
			OmenBarList:SetPoint( "TOPRIGHT", nUI.info_frame.stats, "TOPRIGHT", -2, 0 );
			OmenBarList:SetPoint( "BOTTOMLEFT", OmenModuleButtons, "TOPLEFT", -2, 0 );
			OmenBarList:SetPoint( "BOTTOMRIGHT", OmenModuleButtons, "TOPRIGHT", -2, 0 );			
			OmenBarList:SetWidth( nUI.info_frame.stats:GetWidth() );
			
			-- Detatch the options button so we can keep it active even when the
			-- Omen panel is hidden
			
			config:SetParent( nUI.info_frame.stats );
			config:SetScale( 0.42 );
			config:ClearAllPoints();
			config:SetPoint( "BOTTOM", nUI.info_frame.button, "BOTTOMRIGHT", 0, 0 )
			
			-- Set options to make Omen blend in with nUI visually
			
			local options = Omen.Options;

			options["Skin.Title.Hide"] = true;
			options["Skin.Modules.Hide"] = false;
			options["Lock"] = true;
			
			options["Skin.ModuleList.Background.Color.r"] = 0;
			options["Skin.ModuleList.Background.Color.g"] = 0;
			options["Skin.ModuleList.Background.Color.b"] = 0;
			options["Skin.ModuleList.Background.Color.a"] = 0;
						
			options["Skin.ModuleList.Border.Color.r"] = 0;
			options["Skin.ModuleList.Border.Color.g"] = 0;
			options["Skin.ModuleList.Border.Color.b"] = 0;
			options["Skin.ModuleList.Border.Color.a"] = 0;
			
			options["Skin.BarList.Background.Color.r"] = 0;
			options["Skin.BarList.Background.Color.g"] = 0;
			options["Skin.BarList.Background.Color.b"] = 0;
			options["Skin.BarList.Background.Color.a"] = 0;
						
			options["Skin.BarList.Border.Color.r"] = 0;
			options["Skin.BarList.Border.Color.g"] = 0;
			options["Skin.BarList.Border.Color.b"] = 0;
			options["Skin.BarList.Border.Color.a"] = 0;
			
			Omen:InjectFrameOptions( "ModuleList", Omen.configOptions.args.display.args.moduleList );
			Omen:InjectFrameOptions( "BarList", Omen.configOptions.args.display.args.barList );

			if Omen.activeModule then Omen.activeModule:UpdateLayout(); end
			
			Omen:ResizeBars();

			-- initialize event handling
			
			local event_frame = CreateFrame( "Frame", "$parent_OmenEvents", nUI.info_frame );
			
			nUI.info_frame.omen_events = event_frame;
			
			event_frame:SetScript( "OnEvent", function() nUI:omenEvent(); end );
			event_frame:RegisterEvent( "PLAYER_REGEN_ENABLED" );
			event_frame:RegisterEvent( "PLAYER_REGEN_DISABLED" );
			event_frame:RegisterEvent( "PET_ATTACK_START" );
			event_frame:RegisterEvent( "PET_ATTACK_STOP" );
			
		end			
	end
end

-------------------------------------------------------------------------------

function nUI:omenEvent()
	
	local mode  = nUI.info_frame.modeName[nUI_Config.activeInfoMode];
	local frame = nUI.info_frame.stats.omen2;
	
	if mode == "Omen" then
			
		if event == "PLAYER_REGEN_DISABLED" or event == "PET_ATTACK_START" then
			if not frame:IsShown() then
				frame:Show();
			end
		elseif event == "PLAYER_REGEN_ENABLED" or (event == "PET_ATTACK_STOP" and not InCombatLockdown()) then
			if frame:IsShown() and nUI.AddOn.recount then
				frame:Hide();
			end
		end
	end
end
